@@ -9,6 +9,7 @@
 $mypath = "/home/luca/tryarea" ;# path of the directory in which you are going to work
 
 @sweeps = ( [ [ 1, 2, 3, 4, 5, 6, 7 ] ] );
+#@sweeps = ( [ [ 1 ] ] );
 # DESCRIPTION OF A (MAYBE OVERLAPPING) COORDINATE BLOCK DESCENT. # THE NUMBERS ARE THE VARIABLE NUMBERS.
 # MORE THAN ONE SEARCH MAY BE LISTED. # EACH BLOCK SEARCH IS DESCRIBED AS A SEQUENCE OF LIST VARIABLES.
 # THIS IS THE BLOCK SEARCH STRUCTURE DECLARED EXPLICITLY AS AN ALTERNATIVE TO USING @chanceseed AND @caseseed.
@@ -16,12 +17,13 @@ $mypath = "/home/luca/tryarea" ;# path of the directory in which you are going t
 # @sweeps IS NOT OVERRIDDEN ON THE BASIS OF WHAT IS SPECIFIED IN @chanceseed AND @caseseed. 
 # IT HAS TO BE UNSPECIFIED IF THE SEARCH STRUCTURE HAS TO BE CALCULATE BY THE PROGRAM. @sweepseed MAY BE SPECIFIED IN ITS PLACE.
 
-@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 8, 7 => 3 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
+@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 8, 7 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
+#@varinumbers = ( { 1 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' } ); # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' }, { 1 => '3', 2 => '3', 3 => '3' } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE NUMBER OF ITERATIONS FOR EACH VARIABLES ARE SPECIFIED.
 
-@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 4, 7 => 1 } );
-# IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
+@mediumiters = ( { 1 => 1, 2 => 1, 3 => 1, 4 => 1, 5 => 1, 6 => 5, 7 => 1 } ); # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
+#@mediumiters = ( { 1 => 1 } ); # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
 # IF LEFT UNSPECIFIED IT DEFAULTS TO THE MIDDLE ITERATION FOR EACH VARIABLE.  # IF LEFT UNSPECIFIED IT DEFAULTS TO THE CENTRAL VALUE FOR EACH GIVEN RANGE. 
 
 $file = "testmodish2";  # the root model directory.
@@ -41,6 +43,7 @@ actonexisting_models => { 1 => "y" },
 simtools => { 1 => "esp-r", 
 #2 => "energyplus" 
 },
+#evalfile => "evalfile.pl",
 #reptools => { 1 => "esp-r" },
 ); # 11) THIS MUST BE "y" TO PERFORM BLOCK SEARCH. It checks if it is possible to launch a block search, and if it is does it.
 
@@ -51,8 +54,7 @@ $exeonfiles = "y";
 $preventsim = "n";
 
 $simtitles{1} = [ 
-[ "feb01-feb08", "1 2", "8 2", "20", "1" ], 
-[ "jul01-jul08", "1 7", "8 7", "20", "1" ]
+[ "jan01-dec31", "1 1", "31 12", "20", "1" ], 
 ];
 
 #$simtitles{2} = [ 
@@ -67,14 +69,64 @@ $retrievedata{1} =
 [ 
 [ 
 [ 
-"1 2 1", "7 2 24", "1" # HERE: "start_data_to retrieve", "end_data_to retrieve", "time_step
+"1 1 1", "31 1 24", "1" # HERE: "start_data_to retrieve", "end_data_to retrieve", "time_step
 ]
 ],
 [ 
 [ 
-"1 7 1", "7 7 24", "1" 
+"1 2 1", "28 2 24", "1" 
 ] 
-]
+],
+[ 
+[ 
+"1 3 1", "31 3 24", "1" 
+] 
+],
+[ 
+[ 
+"1 4 1", "30 4 24", "1" 
+] 
+],
+[ 
+[ 
+"1 5 1", "31 5 24", "1" 
+] 
+],
+[ 
+[ 
+"1 6 1", "30 6 24", "1" 
+] 
+],
+[ 
+[ 
+"1 7 1", "31 7 24", "1" 
+] 
+],
+[ 
+[ 
+"1 8 1", "31 8 24", "1" 
+] 
+],
+[ 
+[ 
+"1 9 1", "30 9 24", "1" 
+] 
+],
+[ 
+[ 
+"1 10 1", "31 10 24", "1" 
+] 
+],
+[ 
+[ 
+"1 11 1", "30 11 24", "1" 
+] 
+],
+[ 
+[ 
+"1 12 1", "31 12 24", "1" 
+] 
+],
 ]; 
 
 #@varthemes_report = (
@@ -104,14 +156,122 @@ $reportdata{1} = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @ret
 [ 
 [ 
 	{
-		reporttitle => "feb01-feb07", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "jan01-jan31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
 		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
 		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
 		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 	},
 	{
-		reporttitle => "feb01-feb07", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "jan01-jan31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	},
+	{
+		reporttitle => "jan01-jan31-radent", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "radent", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		#adhoclines => $vals{exportlines}{1} ,
+		afterlines => [ "342-389" ], # LINE TO RETRIEVE
+	},
+	{
+		reporttitle => "jan01-jan31-radabs", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "radabs", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		#adhoclines => $vals{exportlines}{2} ,
+		afterlines => [ "342-389" ], # LINE TO RETRIEVE
+	},
+	{
+		reporttitle => "jan01-jan31-restemp", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "restemp", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		#adhoclines => $vals{exportlines}{3} ,
+		afterlines => [ "342-389" ], # LINE TO RETRIEVE
+	}
+]
+],
+[ 
+[ 
+	{
+		reporttitle => "feb01-feb28", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	},
+	{
+		reporttitle => "feb01-feb28", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	}
+] 
+],
+[ 
+[ 
+	{
+		reporttitle => "mar01-mar31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	},
+	{
+		reporttitle => "mar01-mar31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	},
+	{
+		reporttitle => "mar01-mar31-radent", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "radent", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		#adhoclines => $vals{exportlines}{1} ,
+		afterlines => [ "1758-1805" ], # LINE TO RETRIEVE
+	},
+	{
+		reporttitle => "mar01-mar31-radabs", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "radabs", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		#adhoclines => $vals{exportlines}{2} ,
+		afterlines => [ "1758-1805" ], # LINE TO RETRIEVE
+	},
+	{
+		reporttitle => "mar01-mar31-restemp", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "restemp", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		#adhoclines => $vals{exportlines}{3} ,
+		afterlines => [ "1758-1805" ], # LINE TO RETRIEVE
+	},
+]
+],
+[ 
+[ 
+	{
+		reporttitle => "apr01-apr30", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	},
+	{
+		reporttitle => "apr01-apr30", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
 		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
 		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
@@ -122,41 +282,193 @@ $reportdata{1} = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @ret
 [ 
 [ 
 	{
-		reporttitle => "jul01-jul07", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "may01-may31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
 		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
 		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
 		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 	},
 	{
-		reporttitle => "jul01-jul07", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "may01-may31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
 		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
 		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
 		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 	}
-] 
 ]
+],
+[ 
+[ 
+	{
+		reporttitle => "jun01-jun30", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	},
+	{
+		reporttitle => "jun01-jun30", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	},
+	{
+		reporttitle => "jun01-jun31-radent", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "radent", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		#adhoclines => $vals{exportlines}{1} ,
+		afterlines => [ "3966-4013" ], # LINE TO RETRIEVE
+	},
+	{
+		reporttitle => "jun01-jun31-radabs", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "radabs", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		#adhoclines => $vals{exportlines}{2} ,
+		afterlines => [ "3966-4013" ], # LINE TO RETRIEVE
+	},
+	{
+		reporttitle => "jun01-jun31-restemp", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "restemp", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		#adhoclines => $vals{exportlines}{3} ,
+		afterlines => [ "3966-4013" ], # LINE TO RETRIEVE
+	},
+]
+],
+[ 
+[ 
+	{
+		reporttitle => "jul01-jul31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	},
+	{
+		reporttitle => "jul01-jul31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	}
+]
+],
+[ 
+[ 
+	{
+		reporttitle => "aug01-aug31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	},
+	{
+		reporttitle => "aug01-aug31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	}
+]
+],
+[ 
+[ 
+	{
+		reporttitle => "sep01-sep30", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	},
+	{
+		reporttitle => "sep01-sep30", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	}
+]
+],
+[ 
+[ 
+	{
+		reporttitle => "oct01-oct31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	},
+	{
+		reporttitle => "oct01-oct31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	}
+]
+],
+[ 
+[ 
+	{
+		reporttitle => "nov01-nov30", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	},
+	{
+		reporttitle => "nov01-nov30", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	}
+]
+],
+[ 
+[ 
+	{
+		reporttitle => "dec01-dec31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "tempsstats", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "Ann" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	},
+	{
+		reporttitle => "dec01-dec31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		themereport => "loads", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
+		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
+		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
+		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+	}
+]
+],
 ];
 
-
 #$vals{skipfile} = "skipfile.txt";
 #$vals{skipreport} = " ( ( $simtitle =~ /_1-2/ ) or ( $simtitle =~ /_2-2/ ) or ( $simtitle =~ /_3-2/ ) or ( $simtitle =~ /_4-2/ ) or ( $simtitle =~ /_5-2/ ) or ( $simtitle =~ /_6-2/ ) ) ";
 #$vals{skipreport} = " ( ( \$simtitle =~ /_1-2/ ) or ( \$simtitle =~ /_2-2/ ) or ( \$simtitle =~ /_3-2/ ) or ( \$simtitle =~ /_4-2/ ) or ( \$simtitle =~ /_5-2/ ) or ( \$simtitle =~ /_6-3/ ) or ( \$simtitle =~ /_6-5/ )) ";
 
-@keepcolumns = ( 
-[ "Feb_Avg_ResT", 16 ], [ "Feb_SolAbsInZ", 31 ], [ "Feb_Rad_EntZ", 32 ], [ "Jul_Avg_ResT", 48 ], 
-[ "Jul_SolAbsInZ", 63 ], [ "Jul_Rad_EntZ", 64 ], 
-); 
+#@keepcolumns = ( 
+#[ "Feb_Avg_ResT", 16 ], [ "Feb_SolAbsInZ", 31 ], [ "Feb_Rad_EntZ", 32 ], [ "Jul_Avg_ResT", 48 ], 
+#[ "Jul_SolAbsInZ", 63 ], [ "Jul_Rad_EntZ", 64 ], 
+#); 
 # COLUMNS TO KEEP FROM THE FILE OF RESULTS. THEY ARE WRITTEN IN PAIRS. 
 # THE FIRST ITEM OF EACH PAIR IS THE OBJECTIVE FUNCTION NAME AND THE SECOND IS THE COLUMN TO KEEP 
 # FROM THE RESULT FILE AND BRING TO THE RESULT SUMMARY.
 
-@weights = ( 0.1666, 0.1666, 0.1666, 0.1666, 0.1666, 0.1666 ); 
+#@weights = ( 0.1666, 0.1666, 0.1666, 0.1666, 0.1666, 0.1666 ); 
 # RATIO OF EACH OBJECTIVE FUNCTION, OVER THE TOTAL OF 1. IT IS RELATIVE TO @keepcolumns. EACH WEIGHT IS RELATIVE TO ONE @keepcolumn pair. THEREFORE THEY MUST BE THE IN THE SAME NUMBER.
 # THESE ARE THE WEIGHTS REGARDING THE OBJECTIVE FUNCTIONS WHICH CONCUR TO DEFINE THE OBJECTIVE FUNCTIONS USED FOR BLOCK COORDINATE DESCENT.
 
-@weightsaim = ( 1, 1, 1, -1, -1, -1 ); 
+#@weightsaim = ( 1, 1, 1, -1, -1, -1 ); 
 # THERE IS A POINT TO POINT CORRENSPONDENCE WITH @weights. THEREFORE THEY MUST BE IN THE SAME NUMBER. A (-1) VALUE TELLS THE PROGRAM THAT THE OBJECTIVE FOR THAT OBJECTIVE FUNCTION IS MINIMIZATION. 
 # A (+1) VALUE TELLS THE PROGRAM THAT THE OBJECTIVE IS MAXIMIZATION. 
 
@@ -305,7 +617,7 @@ $vals{1}{5}{obs_modify} =
 [   
 [ 
 "/zones/box.geo",
-[ "i"  , "b", [ [ 0, 0, 0 ], [ 0, 0, 3 ] ] ] # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
+[ "i"  , "b", [ [ 0, 0, 0 ], [ 0, 0, 4 ] ] ] # IT MODIFIES THE DIMENSION OF THE SAME OBSTRUCTION ABOVE
 ]
 ];
 #$vals{1}{5}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
