@@ -63,7 +63,7 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 $target %dowhat
 );
 
-$VERSION = '0.48.1'; # our $VERSION = '';
+$VERSION = '0.49.0'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT is an optimization and morphing program that can be used with simulation programs receiving text files as input and emitting text files as output. It adopts the block coordinate descent optimization method.';
 
 #################################################################################
@@ -1039,7 +1039,7 @@ sub opt
 
 	
 	&start;
-	# eval `cat $configfile`; # The file where the program data are
+	#eval `cat $configfile`; # The file where the program data are
 
 	require $configfile;
 	#if ( not ( $outfile ) ) { $outfile = "$mypath/$file-$fileconfig-feedback.txt"; } 
@@ -1169,7 +1169,7 @@ The morhing and reporting modules of Sim::OPT contain several functions specific
 
 To install Sim::OPT, the command <cpanm Sim::OPT> has to be issued as a superuser. OPT can then be loaded through the command <use Sim::OPT> in a Perl repl. To ease the launch, the batch file "opt" (which can be found packed in the "optw.tar.gz" file in "examples" folder in this distribution) may be copied in a work directory and the command <opt> may be issued (not as a superuser). That command will call the OPT's functions, following the settings specified in the configuration file, which has to be prepared in advance. When launched, OPT will ask the path to that file, which must contain a suitable description of the operations to be accomplished and point to an existing simulation model.
 
-In "optw.tar.gz" there is an example of OPT configuration file for an ESP-r model and another one for EnergyPlus (another building performance simulation program). The defined configuration file may be copied in a chosen work folder for OPT, in which the ESP-r models to be worked may reside. The "$mypath" variable in the configuration file must be set to that work directory.
+In "optw.tar.gz" there is an example of OPT configuration file for an ESP-r model and another one for EnergyPlus (another building performance simulation program) for the same building, with the same settings. The defined configuration file may be copied in a chosen work folder for OPT, in which the ESP-r models to be worked may reside. The "$mypath" variable in the configuration file must be set to that work directory.
 
 To run the morphing functions of OPT without making OPT launch the simulation program, the setting <$exeonfiles = "n";> should be specified in the configuration file. That way the commands will only be printed to a file. This can be aimed to inspect the commands that OPT would give the simulation program.
 
@@ -1185,8 +1185,6 @@ The instance number that has to considered the basic one, corresponding to the r
 
 Where Sim::OPT may be fit for a task? Where a certain exploration is complex and/or when it is to be confronted through decomposition, by dividing a problem in overlapping subproblems; when there aren't slick tools suitable to decomposition-based, simulation-based optimization; when spending a day, or two, or three setting up a model may spare months of work.
 
-Where Sim::OPT may not be fit for the task? Due to its crude interface, for quick shots at small explorations.
-
 Gian Luca Brunetti
 
 gianluca.brunetti@polimi.it
